@@ -1,20 +1,34 @@
 import pathlib
-from healpy.pixelfunc import get_nside
-from matplotlib.pyplot import show
-from cosmoglobe.chain.h5 import model_from_h5
+from enum import Enum
 
 from astropy.utils.data import download_file
 
-data_url = pathlib.Path('http://cosmoglobe.uio.no/')
-   
+from cosmoglobe.chain.h5 import model_from_h5
 
-def skymodel(nside, release=-1, cache=True):
+data_url = pathlib.Path('http://cosmoglobe.uio.no/releases/')
+   
+class Release(Enum):
+    """Class that enumerates Cosmoglobe data releases."""
+
+    BP9 = LATEST = 'BP9/'
+    BP8 = 'BP8'
+    BP7 = 'BP7'
+
+
+releases = {
+    f'{release.name}'.lower(): release for release in Release
+}
+
+
+def sky_model(nside, release=-1, cache=True):
     """Initialize the Cosmoglobe Sky Model from a official release.
 
-    By default, the model is initialized from the latest stable commander3 
+    By default, the model is initialized from the latest stable cosmoglobe data 
     release. The data required to initialize the model is downloaded and cached
     by default every time a unique nside is selected.
 
+    For a list of available releases see the get_releases function.
+
     Parameters
     ----------
     nside : int
@@ -33,12 +47,12 @@ def skymodel(nside, release=-1, cache=True):
     # select latest
     releases = get_releases()
     if release == -1:
-        release = releases[-1]
+        release = Release.LATEST
     else:
         if release not in releases:
             raise ValueError('Invalid release')
 
-    path_to_h5 = data_url / release / filename
+    path_to_h5 = data_url / release.value / filename
 
     # h5_file = download_file(path_to_h5, cache=cache, show_progress=True)
     #download h5 file from the cosmoglobe web and cache
@@ -49,12 +63,6 @@ def skymodel(nside, release=-1, cache=True):
 
 
 def get_releases():
-    """Returns a list of stable Cosmoglobe data release versions. These can be
-    used as input to `cosmoglobe.hub.skymodel`.
-    """
-
-    stable_releases = [
-        'BP8',
-        'BP9',
-    ]
-    return stable_releases
\ No newline at end of file
+    """Returns a list of stable Cosmoglobe data release versions."""
+    
+    return list(releases.keys())
\ No newline at end of file
